<p align="center">
  <img src="https://github.com/user-attachments/assets/8d661d07-453a-4ff8-89e8-153472565b33" />
</p>

**Knew Karma** (/nuː ‘kɑːrmə/) is a Reddit data analysis toolkit designed to provide an extensive range of
functionalities for exploring and analysing Reddit data. It includes a **Command-Line Interface (CLI)**, and an
**Application Programming Interface (API)** to enable an easy integration in other Python Projects.

[![Read the Docs](https://img.shields.io/readthedocs/knewkarma?logo=readthedocs)](https://knewkarma.readthedocs.io) [![CodeQL](https://github.com/bellingcat/knewkarma/actions/workflows/codeql.yml/badge.svg)](https://github.com/bellingcat/knewkarma/actions/workflows/codeql.yml) [![Upload PyPI Package](https://github.com/bellingcat/knewkarma/actions/workflows/python-publish.yml/badge.svg)](https://github.com/bellingcat/knewkarma/actions/workflows/python-publish.yml) [![PyPI - Version](https://img.shields.io/pypi/v/knewkarma?logo=pypi&link=https%3A%2F%2Fpypi.org%2Fproject%2Fknewkarma)](https://pypi.org/project/knewkarma) [![Release Snap Package](https://github.com/bellingcat/knewkarma/actions/workflows/snapstore-publish.yml/badge.svg)](https://github.com/bellingcat/knewkarma/actions/workflows/snapstore-publish.yml) [![Snap version](https://img.shields.io/snapcraft/v/knewkarma/latest/stable?logo=snapcraft&color=%23BB431A)](https://snapcraft.io/knewkarma) [![BuyMeACoffee](https://img.shields.io/badge/Buy%20Me%20a%20Coffee-ffdd00?style=flat&logo=buy-me-a-coffee&logoColor=black)](https://buymeacoffee.com/rly0nheart)

## Documentation

[Read the Docs](https://knewkarma.readthedocs.io) for the *Feature Overview*, *Installation*, *Integration* and
*Usage* instructions.

![readthedocs](https://github.com/user-attachments/assets/41e82e05-f523-4fe3-bb31-fc295ae2ae70)

## Important Note on Data Fetching

Knew Karma is designed to fetch recent data from Reddit. It directly interacts with the Reddit API to access up-to-date
information, including the latest posts, comments, and user activity.

If you need to access historical Reddit data, I recommend using the [Pushshift API](https://api.pushshift.io/docs),
which is
specifically designed for retrieving large volumes of historical data, including posts, comments, and
other Reddit activity.

## Star History

<a href="https://star-history.com/#bellingcat/knewkarma&Date">
 <picture>
   <source media="(prefers-color-scheme: dark)" srcset="https://api.star-history.com/svg?repos=bellingcat/knewkarma&type=Date&theme=dark" />
   <source media="(prefers-color-scheme: light)" srcset="https://api.star-history.com/svg?repos=bellingcat/knewkarma&type=Date" />
   <img alt="Star History Chart" src="https://api.star-history.com/svg?repos=bellingcat/knewkarma&type=Date" />
 </picture>
</a>

## License

MIT License © [Richard Mwewa](https://gravatar.com/rly0nheart)

